summaryrefslogtreecommitdiff
path: root/include/hwtimer.h
diff options
context:
space:
mode:
authorRandall Spangler <rspangler@chromium.org>2012-05-11 12:26:49 -0700
committerRandall Spangler <rspangler@chromium.org>2012-05-11 13:36:34 -0700
commit27e8bdb7c099ff4642c5c1d567029467da35da4f (patch)
treea22aa72b80161b73341bb633cee1157597e0b453 /include/hwtimer.h
parent2f2a5d90224a1a408c6eca408e4d6e87f0fa0503 (diff)
downloadchrome-ec-27e8bdb7c099ff4642c5c1d567029467da35da4f.tar.gz
Maintain timer value across sysjumps and clean up init debug output
This helps us keep track of how long vboot is taking on the EC. Signed-off-by: Randall Spangler <rspangler@chromium.org> BUG=chrome-os-partner:9651 TEST=reboot system and look at debug log. time shouldn't start over after it jumps to image A. Change-Id: Iad86e90d42dabf1c67b2c2be80dda1151cf9a288
Diffstat (limited to 'include/hwtimer.h')
-rw-r--r--include/hwtimer.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/include/hwtimer.h b/include/hwtimer.h
index ae0c634163..4ebc254fa5 100644
--- a/include/hwtimer.h
+++ b/include/hwtimer.h
@@ -24,11 +24,12 @@ void __hw_clock_event_clear(void);
uint32_t __hw_clock_source_read(void);
/**
* Initializes the hardware timer used to provide clock services.
*
* It returns the IRQ number of the timer routine.
*/
-int __hw_clock_source_init(void);
+int __hw_clock_source_init(uint32_t start_t);
/**
* Searches the next deadline and program it in the timer hardware.
@@ -24,11 +24,12 @@ void __hw_clock_event_clear(void);
uint32_t __hw_clock_source_read(void);
/**
- * Initializes the hardware timer used to provide clock services.
+ * Initializes the hardware timer used to provide clock services, using the
+ * specified start timer value.
*
* It returns the IRQ number of the timer routine.